#
# spec file for package utempter
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libutempter0
%define utmpGroup utmp
Name:           utempter
Version:        1.2.1
Release:        2.2
Summary:        A privileged helper for utmp and wtmp updates
License:        LGPL-2.1-or-later
Group:          Productivity/Security
URL:            https://github.com/altlinux/libutempter/
Source:         http://ftp.altlinux.org/pub/people/ldv/utempter/lib%{name}-%{version}.tar.gz
Source1:        http://ftp.altlinux.org/pub/people/ldv/utempter/lib%{name}-%{version}.tar.gz.asc
Source2:        baselibs.conf
Source3:        %{name}.keyring
Patch0:         utempter.eal3.diff
Patch1:         utempter-no-staticlib.patch

%description
Utempter is a utility that allows non-privileged applications such as
terminal emulators to modify the utmp database without having to be
setuid root.

%package devel
Summary:        Development files for utempter
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
Utempter is a privileged helper for utmp and wtmp updates.  This
package contains the development files needed.

%package -n %{lname}
Summary:        Shared library of utempter
Group:          Development/Libraries/C and C++
Requires(post): permissions
Requires(pre):  group(%{utmpGroup})
Provides:       %{name} = %{version}
Obsoletes:      %{name} < 0.5.6

%description -n %{lname}
Utempter is a privileged helper for utmp and wtmp updates.  This
package contains the library used by applications.

%prep
%autosetup -p1 -n lib%{name}-%{version}

%build
make %{?_smp_mflags} RPM_OPT_FLAGS="%{optflags} -fPIC" CC="gcc" libexecdir=%{_libexecdir}

%install
make libdir=%{_libdir} libexecdir=%{_libexecdir} DESTDIR=%{buildroot} install

%verifyscript -n %{lname}
%verify_permissions -e %{_libexecdir}/utempter/utempter

%post -n %{lname}
%set_permissions %{_libexecdir}/utempter/utempter
/sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license COPYING
%dir %{_libexecdir}/utempter
%attr(02755, root, %{utmpGroup}) %{_libexecdir}/utempter/utempter
%attr(755,root,root) %{_libdir}/libutempter.so.*
%attr(644,root,root) %doc %{_mandir}/man8/*

%files devel
%license COPYING
%attr(755,root,root) %{_libdir}/libutempter.so
%attr(644,root,root) %{_includedir}/utempter.h
%attr(644,root,root) %doc %{_mandir}/man3/*

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Apr 10 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- version update to 1.2.1
  * utempter: relaxed host argument validation: it is now allowed
    to contain spaces except in the first character.
- switch source from ftp to http
* Mon Sep 28 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix License, libutempter has been LGPL-2.1+ for the last 19 years
- Fix utempter.8 man page to match real parameters
- Remove erroneous links to utempter.8 man page
- Clean up spec file
* Thu Sep  3 2020 Marcus Meissner <meissner@suse.com>
- fixed utempter location after libexecdir change (bsc#1175925)
* Wed May  6 2020 pgajdos@suse.com
- version update to 1.2.0
  * maintenance work:
    https://github.com/altlinux/libutempter/commits/
- modified patches
  %% utempter-no-staticlib.patch (refreshed)
- modified sources
  %% utempter.keyring
- set now libexecdir=%%{_libexecdir} as utemper binary complies FHS
  definition
* Fri Feb 23 2018 fvogt@suse.com
- Use %%license (boo#1082318)
* Wed Sep 13 2017 schwab@linux-m68k.org
- Pre-require group(%%{utmpGroup})
* Thu Nov 13 2014 tchvatal@suse.com
- remove /sbin/ldconfig -n $DESTDIR%%{_libdir} as it should be not
  needed in install phase
- Remove Requires: %%name as there is no name and adjust obsolete
  as there exist version 0.5.5.6 which is larger than the provides
- Remove sle10 obsolete for ppc64 utempter-64bit
- Clean-up with spec-cleaner
* Thu Aug 14 2014 fcrozat@suse.com
- Obsoletes utempter-32bit in libutempter0-32bit.
* Fri Jun 21 2013 meissner@suse.com
- remove gpg offline checking to avoid buildloops. will be
  done by source service.
* Wed Jun  5 2013 meissner@suse.com
- updated to 1.1.6 upstream (bnc#823302)
  - new apis (old are staying)
- utempter-ppc64.patch: is upstream, removed
- utempter-0.5.5-pie.diff: done differently, removed
- utempter-no-staticlib.patch: no static library wanted
- gpg source tarball checking
- hooked up permissions framework correctly
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Sat Oct 15 2011 andrea.turrini@gmail.com
- fixed typo in utempter.spec
* Tue Oct  4 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Thu Nov 11 2010 aj@suse.de
- Use group utmp for utempter (bnc#652877).
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Thu Sep  9 2010 aj@suse.de
- Split up devel package.
* Mon May 10 2010 meissner@suse.de
- handle ppc64 utmp entries with 32bit timeval correctly. bnc#602489
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sat May 27 2006 schwab@suse.de
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jun 20 2005 kukuk@suse.de
- Compile with -fpie/-pie
* Thu Aug  5 2004 okir@suse.de
- Updated to latest upstream version
* Tue Apr 20 2004 okir@suse.de
- Fix incorrect check for /../ in path names (#39169)
* Fri Jan 16 2004 thomas@suse.de
- added man-page utempter.8 (EAL3)
* Sun Jan 11 2004 adrian@suse.de
- add %%run_ldconfig
* Fri Apr 12 2002 okir@suse.de
- well, if the files list says %%_libdir, one should make sure
  the shared lib really goes to in %%_libdir :)
* Fri Mar  8 2002 kukuk@suse.de
- Create libutemtper.so.0 link and include it in RPM [Bug #14672]
* Tue Jan 29 2002 okir@suse.de
- %%files list uses %%_libdir rather than /usr/lib
* Fri Jan 25 2002 okir@suse.de
- Initial package.
